# -*- coding: utf-8 -*-
"""
SFC - The SyFi Form Compiler
"""

# Import whole language for defining a form
from ufl import *

# Submodules
#import common
#import representation
#import codegeneration

# Options handling
from sfc.common import version
from sfc.common import default_options as default_parameters
from sfc.common import set_logging_level


# Function for compiling a UFL element into UFC code
#from compiler import compile_element # Merge with jit if we want it.

# Function for compiling a UFL form into UFC code
#from compiler import compile_form

# Function for compiling a form and importing it on the fly
from sfc.jit import generate_code, cache_signature, jit, jitf

__version__ = "0.6.1"
__author__ = "Martin Sandve Alnæs"


